@@ -530,7 +530,10 @@ mockPatientProfiles <- function(connectionDetails = list(
 
   # into database
   db <- connectionDetails[["con"]]
-  writeSchema <- strsplit(connectionDetails[["write_schema"]], "\\.")[[1]]
+  writeSchema <- c(
+    "schema" = strsplit(connectionDetails[["write_schema"]], "\\.")[[1]],
+    "prefix" = connectionDetails[["mock_prefix"]]
+  )
 
   tablesToInsert <- c(
     "drug_strength", "drug_exposure", "person", "observation_period",
@@ -540,11 +543,9 @@ mockPatientProfiles <- function(connectionDetails = list(
   for (tab in tablesToInsert) {
     DBI::dbWriteTable(
       conn = db,
-      name = CDMConnector::inSchema(writeSchema,
-                                    table = paste0(
-                                      connectionDetails[["mock_prefix"]],
-                                                   tab)),
-      value = eval(parse(text = tab)), overwrite = TRUE
+      name = CDMConnector::inSchema(schema = writeSchema, table = tab),
+      value = get(tab),
+      overwrite = TRUE
     )
   }
 
