@@ -186,3 +186,58 @@ test_that("with and with overall groups and strata", {
   CDMConnector::cdm_disconnect(cdm)
 
 })
+
+test_that("obscure", {
+  x <- dplyr::tibble(
+    s = c("g1", "g1", "g2", "g1&&g2", "g2", "g1&&g2"),
+    v1 = c(1, 2, 3, 4, 6, 3),
+    v2 = c("a", "b", "a&&b", "b", "0", "0&&ab"),
+    v3 = c(0, 1, 0, 1, 1, 0),
+    v4 = as.Date(c(
+      "2021-05-12", "2012-05-15", "2023-11-30", "2015-12-10", "2014-01-12",
+      "1993-04-190"
+    ))
+  )
+
+  # minCellCount = 1
+  s <- summariseResult(x, minCellCount = 1)
+  expect_true(nrow(s) == 25)
+  expect_true(sum(s$estimate[!is.na(s$estimate)] == "<1") == 0)
+  expect_true(sum(is.na(s$estimate)) == 0)
+
+  # minCellCount = 2
+  s <- summariseResult(x, minCellCount = 2)
+  expect_true(nrow(s) == 25)
+  expect_true(sum(s$estimate[!is.na(s$estimate)] == "<2") == 4)
+  expect_true(sum(is.na(s$estimate)) == 4)
+
+  # minCellCount = 3
+  s <- summariseResult(x, minCellCount = 3)
+  expect_true(nrow(s) == 25)
+  expect_true(sum(s$estimate[!is.na(s$estimate)] == "<3") == 8)
+  expect_true(sum(is.na(s$estimate)) == 8)
+
+  # minCellCount = 4
+  s <- summariseResult(x, minCellCount = 4)
+  expect_true(nrow(s) == 25)
+  expect_true(sum(s$estimate[!is.na(s$estimate)] == "<4") == 9)
+  expect_true(sum(is.na(s$estimate)) == 9)
+
+  # minCellCount = 5
+  s <- summariseResult(x, minCellCount = 5)
+  expect_true(nrow(s) == 25)
+  expect_true(sum(s$estimate[!is.na(s$estimate)] == "<5") == 9)
+  expect_true(sum(is.na(s$estimate)) == 9)
+
+  # minCellCount = 6
+  s <- summariseResult(x, minCellCount = 6)
+  expect_true(nrow(s) == 25)
+  expect_true(sum(s$estimate[!is.na(s$estimate)] == "<6") == 9)
+  expect_true(sum(is.na(s$estimate)) == 9)
+
+  # minCellCount = 7
+  s <- summariseResult(x, minCellCount = 7)
+  expect_true(nrow(s) == 25)
+  expect_true(sum(s$estimate[!is.na(s$estimate)] == "<7") == 1)
+  expect_true(sum(is.na(s$estimate)) == 24)
+})
